OiRA

Help

1. Voorbereiding
3. Inventarisatie + Evaluatie
   1. 1 Commercial manned guarding
   2. Ω Bijkomende risico’s (door u toegevoegd)
      1. Ω.1 The entrance floor is often wet
   - Niet bekekeken
   - Overgeslagen
   - Risico niet aanwezig
   - Risico aanwezig
4. Plan van aanpak
5. Rapport
6. Status 0%

Indien u risico's hebt vastgesteld die niet in de tool zijn opgenomen, kunt u deze nu toevoegen:

Belangrijk: Om te vermijden dat risico’s gedupliceerd worden, raden we u ten sterkste aan om eerst alle voorgaande modules te doorlopen, als u dit nog niet gedaan hebt.

Als u geen risico’s hoeft toe te voegen, ga dan verder.

Vorige Begin plan van aanpak

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More